@@ -1,5 +1,14 @@
 #!/bin/bash
-PYTHON_VERSION=3.7.12
+PYTHON_VERSION=3.7.14
+
+function checkout_version {
+    local repo=$1
+    version=${2:-master}
+    echo Checking out $version on $repo ...
+    (cd ../$repo && git checkout $version && pyenv local $PYTHON_VERSION) && \
+	git pull
+    return $?
+}
 
 # FIXME put some of the below in a common routine
 function finish {
@@ -16,8 +25,7 @@ fi
 mydir=$(dirname $bs)
 fulldir=$(readlink -f $mydir)
 cd $fulldir/..
-(cd ../python-spark && git checkout master && pyenv local $PYTHON_VERSION) && git pull && \
-    (cd ../python-xdis && git checkout master && pyenv local $PYTHON_VERSION) && git pull && \
-    git checkout master && pyenv local $PYTHON_VERSION && git pull
+(cd $fulldir/.. && checkout_version python-spark && checkout_version python-xdis &&
+      checkout_version python-uncompyle6)
 cd $owd
 rm -v */.python-version >/dev/null 2>&1 || true
