@@ -1,4 +1,4 @@
-#  Copyright (c) 2015-2021 Rocky Bernstein
+#  Copyright (c) 2015-2022 Rocky Bernstein
 #  Copyright (c) 2005 by Dan Pascu <dan@windowmaker.org>
 #  Copyright (c) 2000-2002 by hartmut Goebel <h.goebel@crazy-compilers.com>
 #  Copyright (c) 1999 John Aycock
@@ -56,10 +56,12 @@ class PythonParser(GenericASTBuilder):
             "_come_froms",
             "_stmts",
             "attributes",
+            "add_consts",
             "come_froms",
             "except_stmts",
             "exprlist",
             "importlist",
+            "key_value_pairs",
             "kvlist",
             "kwargs",
             "l_stmts",
@@ -73,6 +75,8 @@ class PythonParser(GenericASTBuilder):
             "come_from_loops",
             # Python 3.7+
             "importlist37",
+            # Python < 1.4
+            "args_store",
         ]
         self.collect = frozenset(nt_list)
 
@@ -95,7 +99,7 @@ class PythonParser(GenericASTBuilder):
         # so on but that would require major changes to the
         # semantic actions
         self.singleton = frozenset(
-            ("str", "store", "_stmts", "suite_stmts_opt", "inplace_op")
+            ("str", "store", "_stmts", "suite_stmts_opt", "inplace_op", "add_value")
         )
         # Instructions filled in from scanner
         self.insts = []
@@ -359,7 +363,7 @@ class PythonParser(GenericASTBuilder):
 
 
         stmt   ::= return
-        return ::= ret_expr RETURN_VALUE
+        return ::= return_expr RETURN_VALUE
 
         # "returns" nonterminal is a sequence of statements that ends in a RETURN statement.
         # In later Python versions with jump optimization, this can cause JUMPs
@@ -522,7 +526,7 @@ class PythonParser(GenericASTBuilder):
         expr ::= LOAD_FAST
         expr ::= LOAD_GLOBAL
         expr ::= LOAD_NAME
-        expr ::= _mklambda
+        expr ::= _lambda_body
         expr ::= and
         expr ::= bin_op
         expr ::= call
@@ -566,21 +570,21 @@ class PythonParser(GenericASTBuilder):
 
         yield ::= expr YIELD_VALUE
 
-        _mklambda ::= mklambda
+        _lambda_body ::= lambda_body
 
         expr ::= if_exp
 
-        ret_expr ::= expr
-        ret_expr ::= ret_and
-        ret_expr ::= ret_or
+        return_expr ::= expr
+        return_expr ::= ret_and
+        return_expr ::= ret_or
 
-        ret_expr_or_cond ::= ret_expr
-        ret_expr_or_cond ::= if_exp_ret
+        return_expr_or_cond ::= return_expr
+        return_expr_or_cond ::= if_exp_ret
 
-        stmt ::= return_lambda
+        stmt ::= return_expr_lambda
 
-        return_lambda ::= ret_expr RETURN_VALUE_LAMBDA LAMBDA_MARKER
-        return_lambda ::= ret_expr RETURN_VALUE_LAMBDA
+        return_expr_lambda ::= return_expr RETURN_VALUE_LAMBDA LAMBDA_MARKER
+        return_expr_lambda ::= return_expr RETURN_VALUE_LAMBDA
 
         compare        ::= compare_chained
         compare        ::= compare_single
@@ -891,9 +895,9 @@ def python_parser(
 if __name__ == "__main__":
 
     def parse_test(co):
-        from uncompyle6 import PYTHON_VERSION, IS_PYPY
+        from xdis import PYTHON_VERSION_TRIPLE, IS_PYPY
 
-        ast = python_parser(PYTHON_VERSION, co, showasm=True, is_pypy=IS_PYPY)
+        ast = python_parser(PYTHON_VERSION_TRIPLE, co, showasm=True, is_pypy=IS_PYPY)
         print(ast)
         return
 
